@@ -163,6 +163,9 @@ class InfiniboxShareDriver(driver.ShareDriver):
             total_capacity_gb=float(physical_capacity_bytes) / units.Gi,
             free_capacity_gb=float(free_capacity_bytes) / units.Gi,
             reserved_percentage=self.configuration.reserved_share_percentage,
+            reserved_snapshot_percentage=(
+                self.configuration.reserved_share_from_snapshot_percentage
+                or self.configuration.reserved_share_percentage),
             thin_provisioning=self.configuration.infinidat_thin_provision,
             max_over_subscription_ratio=max_over_subscription_ratio,
             provisioned_capacity_gb=provisioned_capacity_gb,
@@ -330,7 +333,7 @@ class InfiniboxShareDriver(driver.ShareDriver):
         # try treating the ip_address parameter as a range of IP addresses:
         ip_network = ipaddress.ip_network(ip_address, strict=False)
         ip_network_hosts = list(ip_network.hosts())
-        if len(ip_network_hosts) == 0:    # /32, single IP address
+        if len(ip_network_hosts) < 2:    # /32, single IP address
             return ip_address.split('/')[0]
         return "{}-{}".format(ip_network_hosts[0], ip_network_hosts[-1])
 
@@ -403,7 +406,7 @@ class InfiniboxShareDriver(driver.ShareDriver):
 
     @infinisdk_to_manila_exceptions
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         name = self._make_share_name(share)
         infinidat_snapshot = self._get_infinidat_snapshot(snapshot)
         infinidat_new_share = infinidat_snapshot.create_snapshot(
