@@ -212,6 +212,9 @@ class LVMShareDriver(LVMMixin, driver.ShareDriver):
             'storage_protocol': 'NFS_CIFS',
             'reserved_percentage':
                 self.configuration.reserved_share_percentage,
+            'reserved_snapshot_percentage':
+                (self.configuration.reserved_share_from_snapshot_percentage
+                    or self.configuration.reserved_share_percentage),
             'snapshot_support': True,
             'create_share_from_snapshot_support': True,
             'revert_to_snapshot_support': True,
@@ -233,6 +236,7 @@ class LVMShareDriver(LVMMixin, driver.ShareDriver):
             'total_capacity_gb': float(total_size),
             'free_capacity_gb': float(free_size),
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
         }, ]
 
     def create_share(self, context, share, share_server=None):
@@ -272,7 +276,8 @@ class LVMShareDriver(LVMMixin, driver.ShareDriver):
 
             retries = 10 if retry_busy_device else 1
 
-            @utils.retry(exception.ShareBusyException, retries=retries)
+            @utils.retry(retry_param=exception.ShareBusyException,
+                         retries=retries)
             def _unmount_device_with_retry():
                 try:
                     self._execute('umount', '-f', mount_path, run_as_root=True)
