@@ -15,13 +15,12 @@
 
 import copy
 import datetime
+from unittest import mock
 
 import ddt
-import mock
 from oslo_config import cfg
 from oslo_serialization import jsonutils
 from oslo_utils import uuidutils
-import six
 import webob
 
 from manila.api.openstack import wsgi
@@ -40,6 +39,7 @@ from manila.tests import db_utils
 
 
 CONF = cfg.CONF
+SG_GRADUATION_VERSION = '2.55'
 
 
 @ddt.ddt
@@ -50,13 +50,13 @@ class ShareGroupAPITest(test.TestCase):
         super(ShareGroupAPITest, self).setUp()
         self.controller = share_groups.ShareGroupController()
         self.resource_name = self.controller.resource_name
-        self.fake_share_type = {'id': six.text_type(uuidutils.generate_uuid())}
+        self.fake_share_type = {'id': uuidutils.generate_uuid()}
         self.fake_share_group_type = {
-            'id': six.text_type(uuidutils.generate_uuid())}
+            'id': uuidutils.generate_uuid()}
         self.api_version = '2.34'
         self.request = fakes.HTTPRequest.blank(
             '/share-groups', version=self.api_version, experimental=True)
-        self.flags(rpc_backend='manila.openstack.common.rpc.impl_fake')
+        self.flags(transport_url='rabbit://fake:fake@mqhost:5672')
         self.admin_context = context.RequestContext('admin', 'fake', True)
         self.member_context = context.RequestContext('fake', 'fake')
         self.mock_policy_check = self.mock_object(
@@ -137,25 +137,36 @@ class ShareGroupAPITest(test.TestCase):
         expected_share_group['links'] = mock.ANY
         return share_group, expected_share_group
 
-    def test_share_group_create(self):
+    def _get_fake_custom_request_and_context(self, microversion, experimental):
+        req = fakes.HTTPRequest.blank(
+            '/share-groups', version=microversion, experimental=experimental)
+        req_context = req.environ['manila.context']
+        return req, req_context
+
+    @ddt.data({'microversion': '2.34', 'experimental': True},
+              {'microversion': SG_GRADUATION_VERSION, 'experimental': False})
+    @ddt.unpack
+    def test_share_group_create(self, microversion, experimental):
         fake, expected = self._get_fake_share_group()
         self.mock_object(share_types, 'get_default_share_type',
                          mock.Mock(return_value=self.fake_share_type))
         self.mock_object(self.controller.share_group_api, 'create',
                          mock.Mock(return_value=fake))
+        req, req_context = self._get_fake_custom_request_and_context(
+            microversion, experimental)
         body = {"share_group": {}}
 
-        res_dict = self.controller.create(self.request, body)
+        res_dict = self.controller.create(req, body)
 
         self.controller.share_group_api.create.assert_called_once_with(
-            self.context, share_group_type_id=self.fake_share_group_type['id'],
+            req_context, share_group_type_id=self.fake_share_group_type['id'],
             share_type_ids=[self.fake_share_type['id']])
         self.assertEqual(expected, res_dict['share_group'])
         self.mock_policy_check.assert_called_once_with(
-            self.context, self.resource_name, 'create')
+            req_context, self.resource_name, 'create')
 
     def test_group_create_invalid_group_snapshot_state(self):
-        fake_snap_id = six.text_type(uuidutils.generate_uuid())
+        fake_snap_id = uuidutils.generate_uuid()
         self.mock_object(
             self.controller.share_group_api, 'create',
             mock.Mock(side_effect=exception.InvalidShareGroupSnapshot(
@@ -262,6 +273,7 @@ class ShareGroupAPITest(test.TestCase):
 
         self.controller.share_group_api.create.assert_called_once_with(
             self.context, availability_zone_id=fake_az_id,
+            availability_zone=fake_az_name,
             share_group_type_id=self.fake_share_group_type['id'],
             share_type_ids=[self.fake_share_type['id']])
         share_groups.db.availability_zone_get.assert_called_once_with(
@@ -386,8 +398,8 @@ class ShareGroupAPITest(test.TestCase):
             self.context, self.resource_name, 'create')
 
     def test_sg_create_with_source_sg_snapshot_id_and_share_network(self):
-        fake_snap_id = six.text_type(uuidutils.generate_uuid())
-        fake_net_id = six.text_type(uuidutils.generate_uuid())
+        fake_snap_id = uuidutils.generate_uuid()
+        fake_net_id = uuidutils.generate_uuid()
         self.mock_object(share_types, 'get_default_share_type',
                          mock.Mock(return_value=self.fake_share_type))
         mock_api_call = self.mock_object(
@@ -408,7 +420,7 @@ class ShareGroupAPITest(test.TestCase):
             self.context, self.resource_name, 'create')
 
     def test_share_group_create_with_source_sg_snapshot_id(self):
-        fake_snap_id = six.text_type(uuidutils.generate_uuid())
+        fake_snap_id = uuidutils.generate_uuid()
         fake_share_group, expected_group = self._get_fake_share_group(
             source_share_group_snapshot_id=fake_snap_id)
         self.mock_object(share_types, 'get_default_share_type',
@@ -432,7 +444,7 @@ class ShareGroupAPITest(test.TestCase):
             self.context, self.resource_name, 'create')
 
     def test_share_group_create_with_share_network_id(self):
-        fake_net_id = six.text_type(uuidutils.generate_uuid())
+        fake_net_id = uuidutils.generate_uuid()
         fake_group, expected_group = self._get_fake_share_group(
             share_network_id=fake_net_id)
 
@@ -457,7 +469,7 @@ class ShareGroupAPITest(test.TestCase):
             self.context, self.resource_name, 'create')
 
     def test_sg_create_no_default_share_type_with_share_group_snapshot(self):
-        fake_snap_id = six.text_type(uuidutils.generate_uuid())
+        fake_snap_id = uuidutils.generate_uuid()
         fake, expected = self._get_fake_share_group()
         self.mock_object(share_types, 'get_default_share_type',
                          mock.Mock(return_value=None))
@@ -527,7 +539,7 @@ class ShareGroupAPITest(test.TestCase):
             self.context, self.resource_name, 'create')
 
     def test_share_group_create_source_group_snapshot_not_in_available(self):
-        fake_snap_id = six.text_type(uuidutils.generate_uuid())
+        fake_snap_id = uuidutils.generate_uuid()
         body = {
             "share_group": {
                 "source_share_group_snapshot_id": fake_snap_id,
@@ -543,7 +555,7 @@ class ShareGroupAPITest(test.TestCase):
             self.context, self.resource_name, 'create')
 
     def test_share_group_create_source_group_snapshot_does_not_exist(self):
-        fake_snap_id = six.text_type(uuidutils.generate_uuid())
+        fake_snap_id = uuidutils.generate_uuid()
         body = {
             "share_group": {"source_share_group_snapshot_id": fake_snap_id}
         }
@@ -599,7 +611,7 @@ class ShareGroupAPITest(test.TestCase):
                                 self.controller.create,
                                 self.request, body)
 
-        self.assertIn('unknown_field', six.text_type(exc))
+        self.assertIn('unknown_field', str(exc))
         self.mock_policy_check.assert_called_once_with(
             self.context, self.resource_name, 'create')
 
@@ -621,7 +633,11 @@ class ShareGroupAPITest(test.TestCase):
         self.mock_policy_check.assert_called_once_with(
             self.context, self.resource_name, 'create')
 
-    def test_share_group_update_with_name_and_description(self):
+    @ddt.data({'microversion': '2.34', 'experimental': True},
+              {'microversion': SG_GRADUATION_VERSION, 'experimental': False})
+    @ddt.unpack
+    def test_share_group_update_with_name_and_description(
+            self, microversion, experimental):
         fake_name = 'fake_name'
         fake_description = 'fake_description'
         fake_group, expected_group = self._get_fake_share_group(
@@ -630,22 +646,23 @@ class ShareGroupAPITest(test.TestCase):
                          mock.Mock(return_value=fake_group))
         self.mock_object(self.controller.share_group_api, 'update',
                          mock.Mock(return_value=fake_group))
+        req, req_context = self._get_fake_custom_request_and_context(
+            microversion, experimental)
         body = {
             "share_group": {
                 "name": fake_name,
                 "description": fake_description,
             }
         }
-        context = self.request.environ['manila.context']
 
-        res_dict = self.controller.update(self.request, fake_group['id'], body)
+        res_dict = self.controller.update(req, fake_group['id'], body)
 
         self.controller.share_group_api.update.assert_called_once_with(
-            context, fake_group,
+            req_context, fake_group,
             {"name": fake_name, "description": fake_description})
         self.assertEqual(expected_group, res_dict['share_group'])
         self.mock_policy_check.assert_called_once_with(
-            self.context, self.resource_name, 'update')
+            req_context, self.resource_name, 'update')
 
     def test_share_group_update_group_not_found(self):
         body = {"share_group": {}}
@@ -676,7 +693,7 @@ class ShareGroupAPITest(test.TestCase):
                                 self.controller.update,
                                 self.request, 'fake_id', body)
 
-        self.assertIn('unknown_field', six.text_type(exc))
+        self.assertIn('unknown_field', str(exc))
         self.mock_policy_check.assert_called_once_with(
             self.context, self.resource_name, 'update')
 
@@ -687,20 +704,25 @@ class ShareGroupAPITest(test.TestCase):
                                 self.controller.update,
                                 self.request, 'fake_id', body)
 
-        self.assertIn('share_types', six.text_type(exc))
+        self.assertIn('share_types', str(exc))
         self.mock_policy_check.assert_called_once_with(
             self.context, self.resource_name, 'update')
 
-    def test_share_group_list_index(self):
+    @ddt.data({'microversion': '2.31', 'experimental': True},
+              {'microversion': SG_GRADUATION_VERSION, 'experimental': False})
+    @ddt.unpack
+    def test_share_group_list_index(self, microversion, experimental):
         fake, expected = self._get_fake_simple_share_group()
         self.mock_object(
             share_group_api.API, 'get_all', mock.Mock(return_value=[fake]))
+        req, req_context = self._get_fake_custom_request_and_context(
+            microversion, experimental)
 
-        res_dict = self.controller.index(self.request)
+        res_dict = self.controller.index(req)
 
         self.assertEqual([expected], res_dict['share_groups'])
         self.mock_policy_check.assert_called_once_with(
-            self.context, self.resource_name, 'get_all')
+            req_context, self.resource_name, 'get_all')
 
     def test_share_group_list_index_no_groups(self):
         self.mock_object(
@@ -757,8 +779,7 @@ class ShareGroupAPITest(test.TestCase):
                          mock.Mock(return_value=[fake, fake2]))
         req = fakes.HTTPRequest.blank(
             '/share-groups?name~=fake&description~=fake',
-            version='2.36',
-            experimental=True)
+            version='2.36', experimental=True)
         req_context = req.environ['manila.context']
 
         res_dict = self.controller.index(req)
@@ -770,16 +791,21 @@ class ShareGroupAPITest(test.TestCase):
         self.mock_policy_check.assert_called_once_with(
             req_context, self.resource_name, 'get_all')
 
-    def test_share_group_list_detail(self):
+    @ddt.data({'microversion': '2.34', 'experimental': True},
+              {'microversion': SG_GRADUATION_VERSION, 'experimental': False})
+    @ddt.unpack
+    def test_share_group_list_detail(self, microversion, experimental):
         fake, expected = self._get_fake_share_group()
         self.mock_object(
             share_group_api.API, 'get_all', mock.Mock(return_value=[fake]))
+        req, req_context = self._get_fake_custom_request_and_context(
+            microversion, experimental)
 
-        res_dict = self.controller.detail(self.request)
+        res_dict = self.controller.detail(req)
 
         self.assertEqual([expected], res_dict['share_groups'])
         self.mock_policy_check.assert_called_once_with(
-            self.context, self.resource_name, 'get_all')
+            req_context, self.resource_name, 'get_all')
 
     def test_share_group_list_detail_no_groups(self):
         self.mock_object(
@@ -829,17 +855,22 @@ class ShareGroupAPITest(test.TestCase):
         self.mock_policy_check.assert_called_once_with(
             req_context, self.resource_name, 'get_all')
 
-    def test_share_group_delete(self):
+    @ddt.data({'microversion': '2.31', 'experimental': True},
+              {'microversion': SG_GRADUATION_VERSION, 'experimental': False})
+    @ddt.unpack
+    def test_share_group_delete(self, microversion, experimental):
         fake_group, expected_group = self._get_fake_share_group()
         self.mock_object(share_group_api.API, 'get',
                          mock.Mock(return_value=fake_group))
         self.mock_object(share_group_api.API, 'delete')
+        req, req_context = self._get_fake_custom_request_and_context(
+            microversion, experimental)
 
-        res = self.controller.delete(self.request, fake_group['id'])
+        res = self.controller.delete(req, fake_group['id'])
 
         self.assertEqual(202, res.status_code)
         self.mock_policy_check.assert_called_once_with(
-            self.context, self.resource_name, 'delete')
+            req_context, self.resource_name, 'delete')
 
     def test_share_group_delete_group_not_found(self):
         fake_group, expected_group = self._get_fake_share_group()
@@ -865,13 +896,16 @@ class ShareGroupAPITest(test.TestCase):
         self.mock_policy_check.assert_called_once_with(
             self.context, self.resource_name, 'delete')
 
-    def test_share_group_show(self):
+    @ddt.data({'microversion': '2.34', 'experimental': True},
+              {'microversion': SG_GRADUATION_VERSION, 'experimental': False})
+    @ddt.unpack
+    def test_share_group_show(self, microversion, experimental):
         fake, expected = self._get_fake_share_group()
         self.mock_object(
             share_group_api.API, 'get', mock.Mock(return_value=fake))
         req = fakes.HTTPRequest.blank(
-            '/share-groupss/%s' % fake['id'], version=self.api_version,
-            experimental=True)
+            '/share-groupss/%s' % fake['id'], version=microversion,
+            experimental=experimental)
         req_context = req.environ['manila.context']
 
         res_dict = self.controller.show(req, fake['id'])
@@ -882,8 +916,8 @@ class ShareGroupAPITest(test.TestCase):
 
     def test_share_group_show_as_admin(self):
         req = fakes.HTTPRequest.blank(
-            '/share-groupss/my_group_id',
-            version=self.api_version, experimental=True)
+            '/share-groupss/my_group_id', version=self.api_version,
+            experimental=True)
         admin_context = req.environ['manila.context'].elevated()
         req.environ['manila.context'] = admin_context
         fake_group, expected_group = self._get_fake_share_group(
@@ -900,8 +934,8 @@ class ShareGroupAPITest(test.TestCase):
 
     def test_share_group_show_group_not_found(self):
         req = fakes.HTTPRequest.blank(
-            '/share-groupss/myfakegroup',
-            version=self.api_version, experimental=True)
+            '/share-groupss/myfakegroup', version=self.api_version,
+            experimental=True)
         req_context = req.environ['manila.context']
         fake, expected = self._get_fake_share_group(
             ctxt=req_context, id='myfakegroup')
@@ -914,6 +948,19 @@ class ShareGroupAPITest(test.TestCase):
         self.mock_policy_check.assert_called_once_with(
             req_context, self.resource_name, 'get')
 
+    @ddt.data({'microversion': '2.31', 'experimental': True},
+              {'microversion': SG_GRADUATION_VERSION, 'experimental': False})
+    @ddt.unpack
+    def test__reset_status_call(self, microversion, experimental):
+        self.mock_object(self.controller, '_reset_status')
+        req, _junk = self._get_fake_custom_request_and_context(
+            microversion, experimental)
+        sg_id = 'fake'
+        body = {'reset_status': {'status': constants.STATUS_ERROR}}
+
+        self.controller.share_group_reset_status(req, sg_id, body)
+        self.controller._reset_status.assert_called_once_with(req, sg_id, body)
+
     @ddt.data(*fakes.fixture_reset_status_with_different_roles)
     @ddt.unpack
     def test_share_groups_reset_status_with_different_roles(
@@ -925,7 +972,7 @@ class ShareGroupAPITest(test.TestCase):
         body = {action_name: {'status': constants.STATUS_ERROR}}
         req.method = 'POST'
         req.headers['content-type'] = 'application/json'
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.headers['X-Openstack-Manila-Api-Version'] = self.api_version
         req.environ['manila.context'] = ctxt
 
@@ -949,7 +996,7 @@ class ShareGroupAPITest(test.TestCase):
         req.headers['content-type'] = 'application/json'
         action_name = 'force_delete'
         body = {action_name: {}}
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.headers['X-Openstack-Manila-Api-Version'] = self.api_version
         req.environ['manila.context'] = ctxt
 
@@ -959,3 +1006,16 @@ class ShareGroupAPITest(test.TestCase):
 
         # validate response
         self.assertEqual(resp_code, resp.status_int)
+
+    @ddt.data({'microversion': '2.31', 'experimental': True},
+              {'microversion': SG_GRADUATION_VERSION, 'experimental': False})
+    @ddt.unpack
+    def test__force_delete_call(self, microversion, experimental):
+        self.mock_object(self.controller, '_force_delete')
+        req, _junk = self._get_fake_custom_request_and_context(
+            microversion, experimental)
+        sg_id = 'fake'
+        body = {'force_delete': {}}
+
+        self.controller.share_group_force_delete(req, sg_id, body)
+        self.controller._force_delete.assert_called_once_with(req, sg_id, body)
